==> react-image-annotate_ns_demo-5.0.15.tgz: package/Components/MiniDrawer.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { faTag, faVectorSquare } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { Grid } from "@mui/material";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemButton from "@mui/material/ListItemButton";
import ListItemIcon from "@mui/material/ListItemIcon";
import * as React from "react";
import AnnotationInput from "./AnnotationInput";
export default function MiniDrawer(_ref) {
  var image_canvas = _ref.image_canvas,
      state = _ref.state,
      isImageMode = _ref.isImageMode,
      onClickIconSidebarItem = _ref.onClickIconSidebarItem,
      layoutORC = _ref.layoutORC,
      onChangeLayoutORC = _ref.onChangeLayoutORC,
      handleSubmit = _ref.handleSubmit,
      isSubmitDisabled = _ref.isSubmitDisabled,
      _ref$deleteAnnotation = _ref.deleteAnnotationAllow,
      deleteAnnotationAllow = _ref$deleteAnnotation === void 0 ? false : _ref$deleteAnnotation,
      _ref$tilte_key = _ref.tilte_key,
      tilte_key = _ref$tilte_key === void 0 ? "" : _ref$tilte_key;

  var _React$useState = React.useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      open = _React$useState2[0],
      setOpen = _React$useState2[1];

  var faStyle = {
    marginTop: 4,
    width: 16,
    height: 16,
    marginBottom: 4
  };

  window.handleSubmitOcr = function () {
    var intialaAnnotation = JSON.stringify(state);
    var BrushAnnotation = [];
    var deleteAnnotation = deleteAnnotationAllow ? [] : [];
    var annotation = "";

    try {
      annotation = JSON.parse(intialaAnnotation);
    } catch (err) {
      console.log(annotation);
    }

    var upComingRegion = [];

    var finalArr = _defineProperty({}, tilte_key, {
      annotationType: "",
      annotation: [],
      brushAnnotation: [],
      deleteAnnotation: []
    });

    if (annotation.annotationType === "video") {
      upComingRegion = annotation.keyframes || {};
      finalArr = _defineProperty({}, tilte_key, {
        annotationType: "video",
        annotation: upComingRegion || [],
        brushAnnotation: BrushAnnotation || [],
        deleteAnnotation: (deleteAnnotation === null || deleteAnnotation === void 0 ? void 0 : deleteAnnotation.flat()) || []
      });
    } else if (annotation.annotationType === "image") {
      var _annotation, _annotation$images, _annotation$images$;

      upComingRegion = (_annotation = annotation) === null || _annotation === void 0 ? void 0 : (_annotation$images = _annotation.images) === null || _annotation$images === void 0 ? void 0 : (_annotation$images$ = _annotation$images[0]) === null || _annotation$images$ === void 0 ? void 0 : _annotation$images$.regions;
      finalArr = _defineProperty({}, tilte_key, {
        annotationType: "image",
        annotation: upComingRegion || [],
        brushAnnotation: BrushAnnotation || [],
        deleteAnnotation: (deleteAnnotation === null || deleteAnnotation === void 0 ? void 0 : deleteAnnotation.flat()) || []
      });
      return {
        annotation: finalArr,
        ocr_data: layoutORC === null || layoutORC === void 0 ? void 0 : layoutORC.map(function (item) {
          var _item$value = item.value,
              value = _item$value.value,
              name = _item$value.name;
          return {
            title: name,
            content: value
          };
        })
      };
    }
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex"
    }
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(List, null, ["show-tags", "create-box"].map(function (text, index) {
    return /*#__PURE__*/React.createElement(ListItem, {
      key: text,
      disablePadding: true,
      sx: {
        display: "block"
      },
      onClick: function onClick() {
        onClickIconSidebarItem({
          name: text
        });
      }
    }, /*#__PURE__*/React.createElement(ListItemButton, {
      sx: {
        minHeight: 48,
        justifyContent: open ? "initial" : "center",
        px: 2.5
      }
    }, /*#__PURE__*/React.createElement(ListItemIcon, {
      sx: {
        minWidth: 0,
        mr: open ? 3 : "auto",
        justifyContent: "center"
      }
    }, "create-box" === text ? /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      size: "xs",
      fixedWidth: true,
      icon: faVectorSquare,
      color: state.selectedTool === text && "#005f86",
      style: faStyle
    }) : "show-tags" === text ? /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      size: "xs",
      fixedWidth: true,
      icon: faTag,
      color: state.showTags && "#005f86",
      style: faStyle
    }) : null)));
  }))), image_canvas), /*#__PURE__*/React.createElement("div", {
    style: {
      margin: "10px 20px"
    }
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    spacing: (4, 4),
    direction: "column",
    style: {
      maxHeight: "400px",
      overflowY: "scroll",
      overflowX: "hidden",
      minHeight: "400px",
      marginTop: "5px"
    }
  }, layoutORC.map(function (a, index) {
    var value = a.value;
    var key = a.key;
    return a.name && /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      md: 6,
      key: index,
      className: "common_inputBox"
    }, /*#__PURE__*/React.createElement("label", {
      className: "task_formlabel",
      htmlFor: value.name
    }, value.name), /*#__PURE__*/React.createElement(AnnotationInput, {
      rows: 3 // title={value.name}
      ,
      id: value.name,
      value: value.value,
      fullWidth: true,
      onChange: function onChange(e) {
        onChangeLayoutORC(e, key);
      },
      focused: true
    }));
  })))));
}

==> react-image-annotate_ns_demo-5.0.16.tgz: package/Components/MiniDrawer.js <==
import _defineProperty from "@babel/runtime/helpers/esm/defineProperty";
import _slicedToArray from "@babel/runtime/helpers/esm/slicedToArray";
import { faTag, faVectorSquare } from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { Grid } from "@mui/material";
import List from "@mui/material/List";
import ListItem from "@mui/material/ListItem";
import ListItemButton from "@mui/material/ListItemButton";
import ListItemIcon from "@mui/material/ListItemIcon";
import * as React from "react";
import AnnotationInput from "./AnnotationInput";
export default function MiniDrawer(_ref) {
  var image_canvas = _ref.image_canvas,
      state = _ref.state,
      isImageMode = _ref.isImageMode,
      onClickIconSidebarItem = _ref.onClickIconSidebarItem,
      layoutORC = _ref.layoutORC,
      onChangeLayoutORC = _ref.onChangeLayoutORC,
      handleSubmit = _ref.handleSubmit,
      isSubmitDisabled = _ref.isSubmitDisabled,
      _ref$deleteAnnotation = _ref.deleteAnnotationAllow,
      deleteAnnotationAllow = _ref$deleteAnnotation === void 0 ? false : _ref$deleteAnnotation,
      _ref$tilte_key = _ref.tilte_key,
      tilte_key = _ref$tilte_key === void 0 ? "" : _ref$tilte_key;

  var _React$useState = React.useState(false),
      _React$useState2 = _slicedToArray(_React$useState, 2),
      open = _React$useState2[0],
      setOpen = _React$useState2[1];

  var faStyle = {
    marginTop: 4,
    width: 16,
    height: 16,
    marginBottom: 4
  };

  window.handleSubmitOcr = function () {
    var intialaAnnotation = JSON.stringify(state);
    var BrushAnnotation = [];
    var deleteAnnotation = deleteAnnotationAllow ? [] : [];
    var annotation = "";

    try {
      annotation = JSON.parse(intialaAnnotation);
    } catch (err) {
      console.log(annotation);
    }

    var upComingRegion = [];

    var finalArr = _defineProperty({}, tilte_key, {
      annotationType: "",
      annotation: [],
      brushAnnotation: [],
      deleteAnnotation: []
    });

    if (annotation.annotationType === "video") {
      upComingRegion = annotation.keyframes || {};
      finalArr = _defineProperty({}, tilte_key, {
        annotationType: "video",
        annotation: upComingRegion || [],
        brushAnnotation: BrushAnnotation || [],
        deleteAnnotation: (deleteAnnotation === null || deleteAnnotation === void 0 ? void 0 : deleteAnnotation.flat()) || []
      });
    } else if (annotation.annotationType === "image") {
      var _annotation, _annotation$images, _annotation$images$;

      upComingRegion = (_annotation = annotation) === null || _annotation === void 0 ? void 0 : (_annotation$images = _annotation.images) === null || _annotation$images === void 0 ? void 0 : (_annotation$images$ = _annotation$images[0]) === null || _annotation$images$ === void 0 ? void 0 : _annotation$images$.regions;
      finalArr = _defineProperty({}, tilte_key, {
        annotationType: "image",
        annotation: upComingRegion || [],
        brushAnnotation: BrushAnnotation || [],
        deleteAnnotation: (deleteAnnotation === null || deleteAnnotation === void 0 ? void 0 : deleteAnnotation.flat()) || []
      });
      return {
        annotation: finalArr,
        ocr_data: layoutORC === null || layoutORC === void 0 ? void 0 : layoutORC.map(function (item) {
          var _item$value = item.value,
              value = _item$value.value,
              name = _item$value.name;
          return {
            title: name,
            content: value
          };
        })
      };
    }
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
    style: {
      display: "flex"
    }
  }, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(List, null, ["show-tags", "create-box"].map(function (text, index) {
    return /*#__PURE__*/React.createElement(ListItem, {
      key: text,
      disablePadding: true,
      sx: {
        display: "block"
      },
      onClick: function onClick() {
        onClickIconSidebarItem({
          name: text
        });
      }
    }, /*#__PURE__*/React.createElement(ListItemButton, {
      sx: {
        minHeight: 48,
        justifyContent: open ? "initial" : "center",
        px: 2.5
      }
    }, /*#__PURE__*/React.createElement(ListItemIcon, {
      sx: {
        minWidth: 0,
        mr: open ? 3 : "auto",
        justifyContent: "center"
      }
    }, "create-box" === text ? /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      size: "xs",
      fixedWidth: true,
      icon: faVectorSquare,
      color: state.selectedTool === text && "#005f86",
      style: faStyle
    }) : "show-tags" === text ? /*#__PURE__*/React.createElement(FontAwesomeIcon, {
      size: "xs",
      fixedWidth: true,
      icon: faTag,
      color: state.showTags && "#005f86",
      style: faStyle
    }) : null)));
  }))), image_canvas), /*#__PURE__*/React.createElement("div", {
    style: {
      margin: "10px 20px"
    }
  }, /*#__PURE__*/React.createElement(Grid, {
    container: true,
    spacing: (4, 4),
    direction: "column",
    style: {
      maxHeight: "400px",
      overflowY: "scroll",
      overflowX: "hidden",
      minHeight: "400px",
      marginTop: "5px"
    }
  }, layoutORC.map(function (a, index) {
    var value = a.value;
    var key = a.key;
    return value.name && /*#__PURE__*/React.createElement(Grid, {
      item: true,
      xs: 12,
      md: 6,
      key: index,
      className: "common_inputBox"
    }, /*#__PURE__*/React.createElement("label", {
      className: "task_formlabel",
      htmlFor: value.name
    }, value.name), /*#__PURE__*/React.createElement(AnnotationInput, {
      rows: 3 // title={value.name}
      ,
      id: value.name,
      value: value.value,
      fullWidth: true,
      onChange: function onChange(e) {
        onChangeLayoutORC(e, key);
      },
      focused: true
    }));
  })))));
}
